Method: Contentstack::Query#descending

Defined in:
lib/contentstack/query.rb

#descending(field_uid) ⇒ Contentstack::Query

Sort the results in descending order with the given key. Sort the returned entries in descending order of the provided key.

Example

@query = @stack.content_type('category').query
@query.descending

Parameters:

  • field_uid (String)

    The key to order by

Returns:



389
390
391
392
393
# File 'lib/contentstack/query.rb', line 389

def descending(field_uid)
  @query.delete(:asc)
  @query[:desc] = field_uid
  self
end