Method: Contentstack::Query#greater_than
- Defined in:
- lib/contentstack/query.rb
#greater_than(field_uid, value) ⇒ Contentstack::Query
Add a constraint to the query that requires a particular key entry to be greater than the provided value.
Example
@query = @stack.content_type('product').query
@query.greater_than('price', '100')
211 212 213 214 |
# File 'lib/contentstack/query.rb', line 211 def greater_than(field_uid, value) add_query_hash({:"#{field_uid}" => {"$gt" => value}}) self end |