Class: Contentstack::Client
- Inherits:
-
Object
- Object
- Contentstack::Client
- Defined in:
- lib/contentstack/client.rb
Instance Attribute Summary collapse
-
#host ⇒ Object
readonly
Returns the value of attribute host.
-
#region ⇒ Object
readonly
Returns the value of attribute region.
Instance Method Summary collapse
- #asset(uid) ⇒ Object
- #assets ⇒ Object
- #content_type(uid) ⇒ Object
- #content_types ⇒ Object
-
#initialize(api_key, delivery_token, environment, options = {}) ⇒ Client
constructor
Initialize “Contentstack” Client instance.
- #live_preview_query(query = {}) ⇒ Object
-
#sync(params) ⇒ Object
Syncs your Contentstack data with your app and ensures that the data is always up-to-date by providing delta updates.
Constructor Details
#initialize(api_key, delivery_token, environment, options = {}) ⇒ Client
Initialize “Contentstack” Client instance
11 12 13 14 15 16 17 |
# File 'lib/contentstack/client.rb', line 11 def initialize(api_key, delivery_token, environment, ={}) @region = [:region].nil? ? Contentstack::Region::US : [:region] @host = [:host].nil? ? get_default_region_hosts(@region) : [:host] @live_preview = !.key?(:live_preview) ? {} : [:live_preview] @branch = [:branch].nil? ? "" : [:branch] API.init_api(api_key, delivery_token, environment, @host, @branch, @live_preview) end |
Instance Attribute Details
#host ⇒ Object (readonly)
Returns the value of attribute host.
9 10 11 |
# File 'lib/contentstack/client.rb', line 9 def host @host end |
#region ⇒ Object (readonly)
Returns the value of attribute region.
9 10 11 |
# File 'lib/contentstack/client.rb', line 9 def region @region end |
Instance Method Details
#asset(uid) ⇒ Object
31 32 33 |
# File 'lib/contentstack/client.rb', line 31 def asset(uid) Asset.new(uid) end |
#assets ⇒ Object
27 28 29 |
# File 'lib/contentstack/client.rb', line 27 def assets AssetCollection.new end |
#content_type(uid) ⇒ Object
23 24 25 |
# File 'lib/contentstack/client.rb', line 23 def content_type(uid) ContentType.new({uid: uid}) end |
#content_types ⇒ Object
19 20 21 |
# File 'lib/contentstack/client.rb', line 19 def content_types ContentType.all end |
#live_preview_query(query = {}) ⇒ Object
35 36 37 |
# File 'lib/contentstack/client.rb', line 35 def live_preview_query(query={}) API.live_preview_query(query) end |
#sync(params) ⇒ Object
Syncs your Contentstack data with your app and ensures that the data is always up-to-date by providing delta updates
Stack.sync({'init': true}) // For initializing sync
Stack.sync({'init': true, 'locale': 'en-us'}) //For initializing sync with entries of a specific locale
Stack.sync({'init': true, 'start_date': '2018-10-22'}) //For initializing sync with entries published after a specific date
Stack.sync({'init': true, 'content_type_uid': 'session'}) //For initializing sync with entries of a specific content type
Stack.sync({'init': true, 'type': 'entry_published'}) // Use the type parameter to get a specific type of content.Supports 'asset_published', 'entry_published', 'asset_unpublished', 'entry_unpublished', 'asset_deleted', 'entry_deleted', 'content_type_deleted'.
Stack.sync({'pagination_token': '<pagination>'}) // For fetching the next batch of entries using pagination token
Stack.sync({'sync_token': '<sync>'}) // For performing subsequent sync after initial sync
56 57 58 59 |
# File 'lib/contentstack/client.rb', line 56 def sync(params) sync_result = API.get_sync_items(params) SyncResult.new(sync_result) end |