Method: Contentstack::Client#sync
- Defined in:
- lib/contentstack/client.rb
#sync(params) ⇒ Object
Syncs your Contentstack data with your app and ensures that the data is always up-to-date by providing delta updates
Stack.sync({'init': true}) // For initializing sync
Stack.sync({'init': true, 'locale': 'en-us'}) //For initializing sync with entries of a specific locale
Stack.sync({'init': true, 'start_date': '2018-10-22'}) //For initializing sync with entries published after a specific date
Stack.sync({'init': true, 'content_type_uid': 'session'}) //For initializing sync with entries of a specific content type
Stack.sync({'init': true, 'type': 'entry_published'}) // Use the type parameter to get a specific type of content.Supports 'asset_published', 'entry_published', 'asset_unpublished', 'entry_unpublished', 'asset_deleted', 'entry_deleted', 'content_type_deleted'.
Stack.sync({'pagination_token': '<pagination>'}) // For fetching the next batch of entries using pagination token
Stack.sync({'sync_token': '<sync>'}) // For performing subsequent sync after initial sync
76 77 78 79 |
# File 'lib/contentstack/client.rb', line 76 def sync(params) sync_result = API.get_sync_items(params) SyncResult.new(sync_result) end |